@@ -32,6 +32,7 @@ STACK_TYPES = [
     "rds",
     "res",
     "tsk",
+    "lbd",
 ]
 
 MAX_SECURITY_GROUPS = 4
@@ -46,7 +47,6 @@ ENV_BASE = ["dev", "stg", "prd"]
 DEFAULT_REGIONS = [
     "eu-west-1",
     "us-east-1",
-    "eu-central-1",
 ]
 
 AZones = {
@@ -83,6 +83,12 @@ PARAMETERS_SKIP_OVERRIDE_CONDITION = (
     "VPCName",
 )
 
+TROPO_CLASS_TO_CFM = {
+    "AWS::WAFv2::WebACL": {
+        "WebACLRule": "Rule",
+    }
+}
+
 EVAL_TROPO_FUNCTIONS_IN_CFG = (
     "Sub(",
     "Ref(",
@@ -110,6 +116,7 @@ EVAL_PYTHON_FUNCTIONS_IN_CFG = (
     "dict(",
     "eval(",
     "str(",
+    "int(",
     "list(",
     "getattr(",
     "SG_SecurityGroups",
@@ -191,6 +198,11 @@ INSTANCE_FAMILY = [
         "Min": "nano",
         "Max": "2xlarge",
     },
+    {
+        "Name": "t4g",
+        "Min": "nano",
+        "Max": "2xlarge",
+    },
     {
         "Name": "m5a",
         "Min": "large",
@@ -231,6 +243,11 @@ INSTANCE_FAMILY = [
         "Min": "large",
         "Max": "4xlarge",
     },
+    {
+        "Name": "c7g",
+        "Min": "large",
+        "Max": "4xlarge",
+    },
 ]
 
 # override previous cfg with an External one
@@ -265,7 +282,7 @@ CFG_TO_FUNC = {
     "Alarm": {
         "module": "joker",
         "func": ("cloudwatch", "Alarm"),
-        "dep": ["LoadBalancer"],
+        "dep": ["LoadBalancer", "SQSQueue"],
     },
     "ApiGatewayAccount": {"module": "joker", "func": ("apigateway", "Account")},
     "ApiGatewayApiKey": {"module": "joker", "func": ("apigateway", "ApiKey")},
@@ -322,6 +339,10 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("cloudfront", "OriginRequestPolicy"),
     },
+    "CloudFrontResponseHeadersPolicy": {
+        "module": "joker",
+        "func": ("cloudfront", "ResponseHeadersPolicy"),
+    },
     "CodeDeployApp": {"module": "joker", "func": ("codedeploy", "Application")},
     "DynamoDBTable": {"module": "joker", "func": ("dynamodb", "Table")},
     "EC2EIP": {"module": "joker", "func": ("ec2", "EIP")},
@@ -357,6 +378,14 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("elasticache", "ReplicationGroup"),
     },
+    "ElasticLoadBalancingV2ListenerRule": {
+        "module": "joker",
+        "func": ("elasticloadbalancingv2", "ListenerRule"),
+    },
+    "ElasticLoadBalancingV2TargetGroup": {
+        "module": "joker",
+        "func": ("elasticloadbalancingv2", "TargetGroup"),
+    },
     "EventsRule": {
         "module": "events",
         "func": "EVE_EventRules",
@@ -404,7 +433,11 @@ CFG_TO_FUNC = {
         "module": "elasticloadbalancing",
         "func": "LB_ElasticLoadBalancing",
     },
-    "LogsLogGroup": {"module": "joker", "func": ("logs", "LogGroup")},
+    "LogsLogGroup": {
+        "module": "joker",
+        "func": ("logs", "LogGroup"),
+        "dep": ["Lambda"],
+    },
     "ScheduledAction": {"module": "joker", "func": ("autoscaling", "ScheduledAction")},
     "ScalableTarget": {
         "module": "joker",
@@ -418,6 +451,18 @@ CFG_TO_FUNC = {
         "func": ("route53", "RecordSetType"),
         "dep": ["ApiGatewayDomainName", "DBInstance", "EFSFileSystem", "LoadBalancer"],
     },
+    "Route53ResolverEndpoint": {
+        "module": "joker",
+        "func": ("route53resolver", "ResolverEndpoint"),
+    },
+    "Route53ResolverRule": {
+        "module": "joker",
+        "func": ("route53resolver", "ResolverRule"),
+    },
+    "Route53ResolverRuleAssociation": {
+        "module": "joker",
+        "func": ("route53resolver", "ResolverRuleAssociation"),
+    },
     "SecurityGroup": {"module": "ec2", "func": "SG_SecurityGroup"},
     "SecurityGroupIngress": {
         "module": "ec2",
