@@ -10,7 +10,6 @@ from .shared import (
     get_condition,
     add_obj,
 )
-from .route53 import R53_RecordSetRDS
 
 
 class RDSDBInstance(rds.DBInstance):
@@ -132,14 +131,12 @@ def RDS_DB(key):
         if not v["IBOX_ENABLED"]:
             continue
 
+        # trick to keep current in use resname and obj.title
         resname = v.get("IBOX_RESNAME", mapname)
 
         # resources
-        r_DB = RDSDBInstance(mapname)
+        r_DB = RDSDBInstance(resname)
         auto_get_props(r_DB, mapname=mapname)
-        # trick to keep current in use resname obj.title - need to be
-        # executed after invoking auto_get_props
-        r_DB.title = resname
         # trick - when providing DBSnapshotIdentifier
         # or SourceDBInstanceIdentifier some props must not exists
         for m in ["DBName", "MasterUsername", "MasterUserPassword"]:
@@ -155,7 +152,6 @@ def RDS_DB(key):
         for m in ["SourceDBInstanceIdentifier", "DBSnapshotIdentifier"]:
             setattr(r_DB, m, If(f"{mapname}{m}", getattr(r_DB, m), Ref("AWS::NoValue")))
 
-        R53_RecordSetRDS(resname)
         # trick fixed name to avoid reboot for now
         # best way should be to use a name like DBParameterGroup{Engine}
         r_PG = RDSDBParameterGroup("DBParameterGroup1", mapname)
